diff --git a/files/lib/gluon/ssid-changer/ssid-changer.sh b/files/lib/gluon/ssid-changer/ssid-changer.sh
index 26e91e5bad85b246a55c95eb5ff34c97abfc8aa2..ca25f39810ee2a992524dafddffde1a8f1e4be94 100755
--- a/files/lib/gluon/ssid-changer/ssid-changer.sh
+++ b/files/lib/gluon/ssid-changer/ssid-changer.sh
@@ -1,8 +1,17 @@
 #!/bin/sh
 
-MINUTES=1440 # only once every timeframe the SSID will change to OFFLINE (set to 1 minute to change every time the router gets offline)
-FIRST=5 # the first few minutes directly after reboot within which an Offline-SSID always may be activated
-OFFLINE_PREFIX='FF_OFFLINE_' # use something short to leave space for the nodename (no '~' allowed!)
+# only once every timeframe the SSID will change to OFFLINE (set to 1 minute to change every time the router gets offline)
+MINUTES="$(uci get ssid-changer.settings.switch_timeframe -q)"
+# the first few minutes directly after reboot within which an Offline-SSID always may be activated
+: ${MINUTES:=1}
+
+FIRST="$(uci get ssid-changer.settings.first -q)"
+# use something short to leave space for the nodename (no '~' allowed!)
+: ${FIRST:=5}
+
+PREFIX="$(uci get ssid-changer.settings.prefix -q)"
+# generate the ssid with either 'nodename', 'mac' or to use only the prefix: 'none'
+: ${PREFIX:='FF_OFFLINE_'}
 
 if [ "$(uci get ssid-changer.settings.enabled -q)" = '0' ]; then 
 	DISABLED='1'
@@ -10,20 +19,28 @@ else
 	DISABLED='0'
 fi
 
-ONLINE_SSID="$(uci get wireless.client_radio0.ssid -q)"
-: ${ONLINE_SSID:="FREIFUNK"} # if for whatever reason ONLINE_SSID is NULL
+SETTINGS_SUFFIX="$(uci get ssid-changer.settings.suffix -q)"
 
-# generate an Offline SSID with the first and last part of the nodename to allow owner to recognise wich node is down
-NODENAME="$(uname -n)"
-if [ ${#NODENAME} -gt $((30 - ${#OFFLINE_PREFIX})) ]; then # 32 would be possible as well
-	HALF=$(( (28 - ${#OFFLINE_PREFIX} ) / 2 )) # calculate the length of the first part of the node identifier in the offline-ssid
-	SKIP=$(( ${#NODENAME} - $HALF )) # jump to this charakter for the last part of the name
-	OFFLINE_SSID=$OFFLINE_PREFIX${NODENAME:0:$HALF}...${NODENAME:$SKIP:${#NODENAME}} # use the first and last part of the nodename for nodes with long name
-else
-	OFFLINE_SSID="$OFFLINE_PREFIX$NODENAME" # great! we are able to use the full nodename in the offline ssid
+if [ $SETTINGS_SUFFIX = 'nodename' ]; then
+	SUFFIX="$(uname -n)"
+	if [ ${#SUFFIX} -gt $((30 - ${#PREFIX})) ]; then # 32 would be possible as well
+		HALF=$(( (28 - ${#PREFIX} ) / 2 )) # calculate the length of the first part of the node identifier in the offline-ssid
+		SKIP=$(( ${#SUFFIX} - $HALF )) # jump to this charakter for the last part of the name
+		SUFFIX=${SUFFIX:0:$HALF}...${SUFFIX:$SKIP:${#SUFFIX}} # use the first and last part of the nodename for nodes with long name
+	fi
+elif [ $SETTINGS_SUFFIX = 'mac' ]; then
+	SUFFIX="$(uci get network.bat0.macaddr -q)"
+else # 'none'
+	SUFFIX=''
 fi
 
-# maximum simplified, no more ttvn rating
+OFFLINE_SSID="$PREFIX$SUFFIX"
+
+# TODO: ffac tq limits has to be implemented here if enabled
+
+ONLINE_SSID="$(uci get wireless.client_radio0.ssid -q)"
+: ${ONLINE_SSID:="FREIFUNK"} # if for whatever reason ONLINE_SSID is NULL
+
 CHECK="$(batctl gwl -H|grep -v "gateways in range"|wc -l)"
 HUP_NEEDED=0
 if [ "$CHECK" -gt 0 ] || [ "$DISABLED" = '1' ]; then
@@ -37,11 +54,11 @@ if [ "$CHECK" -gt 0 ] || [ "$DISABLED" = '1' ]; then
 	fi
 	CURRENT_SSID="$(grep "^ssid=$OFFLINE_SSID" $HOSTAPD | cut -d"=" -f2)"
 	if [ "$CURRENT_SSID" = "$OFFLINE_SSID" ]; then
-		logger -s -t "gluon-offline-ssid" -p 5 "SSID is $CURRENT_SSID, change to $ONLINE_SSID"
+		logger -s -t "gluon-ssid-changer" -p 5 "SSID is $CURRENT_SSID, change to $ONLINE_SSID"
 		sed -i "s~^ssid=$CURRENT_SSID~ssid=$ONLINE_SSID~" $HOSTAPD
 		HUP_NEEDED=1 # HUP here would be to early for dualband devices
 	else
-		echo "There is something wrong, did not find SSID $ONLINE_SSID or $OFFLINE_SSID"
+		logger -s -t "gluon-ssid-changer" -p 5 "could not set to online state: did neither find SSID '$ONLINE_SSID' nor '$OFFLINE_SSID'. Please reboot"
 	fi
 done
 elif [ "$CHECK" -eq 0 ]; then
@@ -56,11 +73,11 @@ elif [ "$CHECK" -eq 0 ]; then
   		fi
   		CURRENT_SSID="$(grep "^ssid=$ONLINE_SSID" $HOSTAPD | cut -d"=" -f2)"
   		if [ "$CURRENT_SSID" = "$ONLINE_SSID" ]; then
-  			logger -s -t "gluon-offline-ssid" -p 5 "SSID is $CURRENT_SSID, change to $OFFLINE_SSID"
+  			logger -s -t "gluon-ssid-changer" -p 5 "SSID is $CURRENT_SSID, change to $OFFLINE_SSID"
   			sed -i "s~^ssid=$ONLINE_SSID~ssid=$OFFLINE_SSID~" $HOSTAPD
   			HUP_NEEDED=1
   		else
-  			echo "There is something wrong: did neither find SSID '$ONLINE_SSID' nor '$OFFLINE_SSID'"
+  			logger -s -t "gluon-ssid-changer" -p 5 "could not set to offline state: did neither find SSID '$ONLINE_SSID' nor '$OFFLINE_SSID'. Please reboot"
   		fi
 		done
 	fi